==> dde-shell_2.0.15.tar.xz: BUILD/panels/dock/taskmanager/translations/org.deepin.ds.dock.taskmanager_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Rıhtım&apos;dan çıkar</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Rıhtım&apos;a ekle</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Zorla çık</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tümünü Kapat</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Rıhtım&apos;dan çıkar</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Rıhtım&apos;a ekle</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Zorla Çık</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tümünü Kapat</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/dock/taskmanager/translations/org.deepin.ds.dock.taskmanager_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation>Çöp Kutusuna Taşı</translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Rıhtım&apos;dan çıkar</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Rıhtım&apos;a ekle</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Zorla çık</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tümünü Kapat</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Rıhtım&apos;dan çıkar</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Rıhtım&apos;a ekle</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Zorla Çık</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tümünü Kapat</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation>%1 dosya</translation>
    </message>
</context>
</TS>
